@@ -22,15 +22,16 @@ class ResourceView(HandlerMixin, ThrottleMixin, EmitterMixin, ParserMixin, Authe
     api = None
 
     log = True
-
-    allowed_methods = ('GET', )
+    
+    # Since we handle cross-origin XML HTTP requests, let OPTIONS be another default allowed method.
+    allowed_methods = ('GET', 'OPTIONS')
 
     emitters = (XMLTemplateEmitter, JSONTemplateEmitter)
 
     parsers = (FormParser, XMLParser, JSONParser)
 
     callmap = { 'GET': 'get', 'POST': 'post',
-                'PUT': 'put', 'DELETE': 'delete' }
+                'PUT': 'put', 'DELETE': 'delete', 'OPTIONS': 'options' }
 
     @csrf_exempt
     def dispatch(self, request, *args, **kwargs):
